@@ -17,7 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
 
-/* $Id: pcsc_scan.c,v 1.23 2006-10-25 16:08:10 rousseau Exp $ */
+/* $Id: pcsc_scan.c,v 1.26 2007-04-03 20:24:10 rousseau Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -57,7 +57,7 @@ int main(int argc, char *argv[])
 	SCARDCONTEXT hContext;
 	SCARD_READERSTATE_A *rgReaderStates_t = NULL;
 	DWORD dwReaders, dwReadersOld;
-	LPTSTR mszReaders = NULL;
+	LPSTR mszReaders = NULL;
 	char *ptr, **readers = NULL;
 	int nbReaders, i;
 	char atr[MAX_ATR_SIZE*3+1];	/* ATR in ASCII */
@@ -130,7 +130,7 @@ int main(int argc, char *argv[])
 	rv = SCardEstablishContext(SCARD_SCOPE_SYSTEM, NULL, NULL, &hContext);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		printf("SCardEstablishContext: Cannot Connect to Resource Manager %lX\n", rv);
+		printf("SCardEstablishContext: Cannot Connect to Resource Manager: %s (0x%lX)\n", pcsc_stringify_error(rv), rv);
 		return 1;
 	}
 
@@ -158,7 +158,7 @@ get_readers:
 	rv = SCardListReaders(hContext, NULL, NULL, &dwReaders);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		printf("SCardListReader: %lX\n", rv);
+		printf("SCardListReader: %s (0x%lX)\n", pcsc_stringify_error(rv), rv);
 		exit(-1);
 	}
 	dwReadersOld = dwReaders;
@@ -180,7 +180,7 @@ get_readers:
 	rv = SCardListReaders(hContext, NULL, mszReaders, &dwReaders);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		printf("SCardListReader: %lX\n", rv);
+		printf("SCardListReader: %s (0x%lX)\n", pcsc_stringify_error(rv), rv);
 	}
 
 	/* Extract readers from the null separated string and get the total
@@ -283,7 +283,7 @@ get_readers:
 				color_end);
 
 			/* Dump the full current state */
-			printf("  Card state: %s", magenta);
+			printf("  Card state: %s", red);
 
 			if (rgReaderStates_t[current_reader].dwEventState &
 				SCARD_STATE_IGNORE)
@@ -364,13 +364,13 @@ get_readers:
 	} /* while */
 
 	/* If we get out the loop, GetStatusChange() was unsuccessful */
-	printf("SCardGetStatusChange: %lX\n", rv);
+	printf("SCardGetStatusChange: %s (0x%lX)\n", pcsc_stringify_error(rv), rv);
 	
 	/* We try to leave things as clean as possible */
 	rv = SCardReleaseContext(hContext);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		printf("SCardReleaseContext: %lX\n", rv);
+		printf("SCardReleaseContext: %s (0x%lX)\n", pcsc_stringify_error(rv), rv);
 	}
 
 	/* free memory possibly allocated */
